@@ -46,14 +46,14 @@ class GSPeerConnectionBroadcaster:
     @classmethod
     async def create(cls, gsdbs):
         self = GSPeerConnectionBroadcaster()
-        rtconfiList = []
+        self.rtconfiList = []
 
         with picamera.PiCamera() as camera:
             self.gsdbs = gsdbs
             if self.gsdbs.credentials["stunenable"]:
-                rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
+                self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
             if self.gsdbs.credentials["turnenable"]:
-                rtconfiList.append(RTCIceServer(self.gsdbs.credentials["turnserver"],
+                self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["turnserver"],
                                                 self.gsdbs.credentials["turnuser"],
                                                 self.gsdbs.credentials["turnpw"]))
             camera.resolution = (self.gsdbs.credentials["hres"], self.gsdbs.credentials["vres"])
