@@ -27,14 +27,7 @@ class GSPeerConnectionWatcher:
     @classmethod
     async def create(cls, gsdbs, target, onframe=None, onmessage=None, ontrack=None):
         self = GSPeerConnectionWatcher()
-        rtconfiList = []
-        if self.gsdbs.credentials["stunenable"]:
-            rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
-        if self.gsdbs.credentials["turnenable"]:
-            rtconfiList.append(RTCIceServer(self.gsdbs.credentials["turnserver"],
-                                            self.gsdbs.credentials["turnuser"],
-                                            self.gsdbs.credentials["turnpw"]))
-
+        self.rtconfiList = []
         self.sio = socketio.AsyncClient()
         self.gsdbs = gsdbs
         self.onframe = onframe
@@ -43,6 +36,13 @@ class GSPeerConnectionWatcher:
         self.ontrack = ontrack
         self.logger = logging.getLogger(__name__)
 
+        if self.gsdbs.credentials["stunenable"]:
+            self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
+        if self.gsdbs.credentials["turnenable"]:
+            self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["turnserver"],
+                                            self.gsdbs.credentials["turnuser"],
+                                            self.gsdbs.credentials["turnpw"]))
+
         @self.sio.event
         async def connect():
             self.logger.info('connection established')
@@ -57,8 +57,8 @@ class GSPeerConnectionWatcher:
 
         @self.sio.event
         async def offer(id, description):
-            if len(rtconfiList) > 0:
-                pc = RTCPeerConnection(configuration=RTCConfiguration(rtconfiList))
+            if len(self.rtconfiList) > 0:
+                pc = RTCPeerConnection(configuration=RTCConfiguration(self.rtconfiList))
             else:
                 pc = RTCPeerConnection()
 
